@@ -21,22 +21,30 @@ class Report(scooby.Report):
             "localtileserver",
             "flask",
             "flask_caching",
+            "flask_restx",
             "requests",
             "werkzeug",
-            "furl",
             "click",
             "scooby",
         ] + large_image_core
 
         # Optional packages.
         optional = [
+            "gunicorn",
+            "pylibmc",
             "ipyleaflet",
+            "traitlets",
             "shapely",
             "folium",
+            "matplotlib",
+            "colorcet",
+            "cmocean",
             "large_image_source_mapnik",
             "large_image_source_pil",
             "large_image_source_tiff",
+            "large_image_converter",
             "tifftools",
+            "pyvips",
         ]
 
         scooby.Report.__init__(
