@@ -19,6 +19,8 @@ def get_leaflet_tile_layer(
     vmin: Union[Union[float, int], List[Union[float, int]]] = None,
     vmax: Union[Union[float, int], List[Union[float, int]]] = None,
     nodata: Union[Union[float, int], List[Union[float, int]]] = None,
+    scheme: Union[str, List[str]] = None,
+    n_colors: int = 255,
     attribution: str = None,
     **kwargs,
 ):
@@ -53,6 +55,16 @@ def get_leaflet_tile_layer(
         a single band.
     nodata : float
         The value from the band to use to interpret as not valid data.
+    scheme : str
+        This is either ``linear`` (the default) or ``discrete``. If a
+        palette is specified, ``linear`` uses a piecewise linear
+        interpolation, and ``discrete`` uses exact colors from the palette
+        with the range of the data mapped into the specified number of
+        colors (e.g., a palette with two colors will split exactly halfway
+        between the min and max values).
+    n_colors : int
+        The number (positive integer) of colors to discretize the matplotlib
+        color palettes when used.
     attribution : str
         Attribution for the source raster. This
         defaults to a message about it being a local file.
@@ -84,6 +96,9 @@ def get_leaflet_tile_layer(
         vmin=vmin,
         vmax=vmax,
         nodata=nodata,
+        scheme=scheme,
+        n_colors=n_colors,
+        client=True,
     )
     if attribution is None:
         attribution = DEFAULT_ATTRIBUTION
@@ -190,6 +205,8 @@ def get_folium_tile_layer(
     vmin: Union[Union[float, int], List[Union[float, int]]] = None,
     vmax: Union[Union[float, int], List[Union[float, int]]] = None,
     nodata: Union[Union[float, int], List[Union[float, int]]] = None,
+    scheme: Union[str, List[str]] = None,
+    n_colors: int = 255,
     attr: str = None,
     **kwargs,
 ):
@@ -224,6 +241,16 @@ def get_folium_tile_layer(
         a single band.
     nodata : float
         The value from the band to use to interpret as not valid data.
+    scheme : str
+        This is either ``linear`` (the default) or ``discrete``. If a
+        palette is specified, ``linear`` uses a piecewise linear
+        interpolation, and ``discrete`` uses exact colors from the palette
+        with the range of the data mapped into the specified number of
+        colors (e.g., a palette with two colors will split exactly halfway
+        between the min and max values).
+    n_colors : int
+        The number (positive integer) of colors to discretize the matplotlib
+        color palettes when used.
     attr : str
         Folium requires the custom tile source have an attribution. This
         defaults to a message about it being a local file.
@@ -248,6 +275,9 @@ def get_folium_tile_layer(
         vmin=vmin,
         vmax=vmax,
         nodata=nodata,
+        scheme=scheme,
+        n_colors=n_colors,
+        client=True,
     )
     if attr is None:
         attr = DEFAULT_ATTRIBUTION
