@@ -26,8 +26,8 @@ def test_create_tile_client(bahamas_file, processes):
     assert ServerManager.server_count() == 0
     tile_client = TileClient(bahamas_file, processes=processes, debug=True)
     assert tile_client.filename == bahamas_file
-    assert tile_client.port
-    assert tile_client.base_url
+    assert tile_client.server_port
+    assert tile_client.server_base_url
     assert "bounds" in tile_client.metadata()
     assert tile_client.bounds()
     center = tile_client.center()
@@ -41,7 +41,7 @@ def test_create_tile_client(bahamas_file, processes):
     r = requests.get(tile_url)
     r.raise_for_status()
     assert r.content
-    tile_url = tile_client.create_url("/tiles/debug/{z}/{x}/{y}.png".format(z=8, x=72, y=110))
+    tile_url = tile_client.create_url("api/tiles/debug/{z}/{x}/{y}.png".format(z=8, x=72, y=110))
     r = requests.get(tile_url)
     r.raise_for_status()
     assert r.content
@@ -81,8 +81,8 @@ def test_multiple_tile_clients_one_server(bahamas, blue_marble):
     tile_url_a = bahamas.get_tile_url().format(z=8, x=72, y=110)
     tile_url_b = blue_marble.get_tile_url().format(z=8, x=72, y=110)
     assert get_content(tile_url_a) != get_content(tile_url_b)
-    thumb_url_a = bahamas.create_url("thumbnail")
-    thumb_url_b = blue_marble.create_url("thumbnail")
+    thumb_url_a = bahamas.create_url("api/thumbnail")
+    thumb_url_b = blue_marble.create_url("api/thumbnail")
     assert get_content(thumb_url_a) != get_content(thumb_url_b)
 
 
@@ -106,10 +106,10 @@ def test_extract_roi_pixel(bahamas):
 
 
 def test_caching_query_params(bahamas):
-    thumb_url_a = bahamas.create_url("thumbnail")
-    thumb_url_b = bahamas.create_url("thumbnail?band=1")
+    thumb_url_a = bahamas.create_url("api/thumbnail")
+    thumb_url_b = bahamas.create_url("api/thumbnail?band=1")
     assert get_content(thumb_url_a) != get_content(thumb_url_b)
-    thumb_url_c = bahamas.create_url("thumbnail")
+    thumb_url_c = bahamas.create_url("api/thumbnail")
     assert get_content(thumb_url_a) == get_content(thumb_url_c)
 
 
@@ -145,7 +145,7 @@ def test_launch_non_default_server(bahamas_file):
     default = TileClient(bahamas_file)
     diff = TileClient(bahamas_file, port=0)
     assert default.server != diff.server
-    assert default.port != diff.port
+    assert default.server_port != diff.server_port
 
 
 def test_get_or_create_tile_client(bahamas_file, remote_file_url):
@@ -174,3 +174,12 @@ def test_pixel(bahamas):
 def test_histogram(bahamas):
     hist = bahamas.histogram()
     assert len(hist)
+
+
+def test_custom_palette(bahamas):
+    palette = ["#006633", "#E5FFCC", "#662A00", "#D8D8D8", "#F5F5F5"]
+    thumbnail = bahamas.thumbnail(
+        band=1,
+        palette=palette,
+    )
+    assert thumbnail  # TODO: check colors in produced image
